/*
* This file is part of Mancala
*
* Originally from Crazyparking:
*
* Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia
* http://www.indt.org/maemo
*
* adapted:
* Copyright (c) 2009 Reto Zingg
*
* This software is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public License
* as published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA
*
*/
#include <stdio.h>
#include <hgw/hgw.h>
#include "callbacks.h"


// Pause the game
int exit_callback(int errcode) {
    	printf("exit_callback called...\n");
	hgw_context_destroy(hgw_context, HGW_BYE_INACTIVE);
	return 0;
}

// Quit game
int quit_callback(int errcode) {
    	printf("quit_callback called...\n");
	hgw_context_destroy(hgw_context, HGW_BYE_INACTIVE);
	return 0;
}

int flush_callback(int errcode) {
    	printf("quit_callback called...\n");
	hgw_context_destroy(hgw_context, HGW_BYE_INACTIVE);
	return 0;
}
